@@ -1,7 +1,7 @@
 /*
  * wee-debug.c - debug functions
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -29,6 +29,7 @@
 #endif
 #include <string.h>
 #include <time.h>
+#include <sys/time.h>
 #include <gcrypt.h>
 #include <curl/curl.h>
 #include <zlib.h>
@@ -48,6 +49,7 @@
 #include "wee-log.h"
 #include "wee-proxy.h"
 #include "wee-string.h"
+#include "wee-util.h"
 #include "../gui/gui-bar.h"
 #include "../gui/gui-bar-item.h"
 #include "../gui/gui-buffer.h"
@@ -63,6 +65,9 @@
 
 int debug_dump_active = 0;
 
+char *debug_time_name = NULL;
+struct timeval debug_timeval_start = { 0, 0 };
+
 
 /*
  * Writes dump of data to WeeChat log file.
@@ -84,15 +89,9 @@ debug_dump (int crash)
 
     log_printf ("");
     if (crash)
-    {
-        log_printf ("******             WeeChat CRASH DUMP              ******");
-        log_printf ("****** Please send this file to WeeChat developers ******");
-        log_printf ("******    and explain when this crash happened     ******");
-    }
+        log_printf ("****** WeeChat CRASH DUMP ******");
     else
-    {
-        log_printf ("******            WeeChat dump request             ******");
-    }
+        log_printf ("****** WeeChat dump request ******");
 
     gui_window_print_log ();
     gui_buffer_print_log ();
@@ -116,7 +115,7 @@ debug_dump (int crash)
     plugin_print_log ();
 
     log_printf ("");
-    log_printf ("******             End of WeeChat dump             ******");
+    log_printf ("****** End of WeeChat dump ******");
     log_printf ("");
 }
 
@@ -164,11 +163,11 @@ debug_sigsegv ()
     string_iconv_fprintf (stderr, "***\n");
     string_iconv_fprintf (stderr, "*** Please help WeeChat developers to fix this bug:\n");
     string_iconv_fprintf (stderr, "***   1. If you have a core file, please run:  gdb /path/to/weechat core\n");
-    string_iconv_fprintf (stderr, "***      then issue \"bt\" command and send result to developers\n");
-    string_iconv_fprintf (stderr, "***      To enable core files with bash shell: ulimit -c 10000\n");
-    string_iconv_fprintf (stderr, "***   2. Otherwise send backtrace (below) and weechat.log\n");
-    string_iconv_fprintf (stderr, "***      (be careful, private info may be in this file since\n");
-    string_iconv_fprintf (stderr, "***      part of chats are displayed, so remove lines if needed)\n\n");
+    string_iconv_fprintf (stderr, "***      then issue command: \"bt full\" and send result to developers\n");
+    string_iconv_fprintf (stderr, "***      (see user's guide for more info about report of crashes).\n");
+    string_iconv_fprintf (stderr, "***   2. Otherwise send backtrace (below), only if it is a complete trace.\n");
+    string_iconv_fprintf (stderr, "***      Keep the crash log file, just in case developers ask you some info\n");
+    string_iconv_fprintf (stderr, "***      (be careful, private info like passwords may be in this file).\n\n");
 
     weechat_backtrace ();
 
@@ -268,7 +267,7 @@ debug_memory ()
     gui_chat_printf (NULL,
                      _("Memory usage not available (function \"mallinfo\" not "
                        "found)"));
-#endif
+#endif /* HAVE_MALLINFO */
 }
 
 /*
@@ -534,7 +533,7 @@ debug_libs_cb (void *data, const char *signal, const char *type_data,
 #else
     gui_chat_printf (NULL, "    gcrypt: (?)%s",
                      (weechat_no_gcrypt) ? " (not initialized)" : "");
-#endif
+#endif /* GCRYPT_VERSION */
 
     /* display gnutls version */
 #ifdef HAVE_GNUTLS
@@ -545,24 +544,24 @@ debug_libs_cb (void *data, const char *signal, const char *type_data,
 #else
     gui_chat_printf (NULL, "    gnutls: (?)%s",
                      (weechat_no_gnutls) ? " (not initialized)" : "");
-#endif
+#endif /* GNUTLS_VERSION */
 #else
     gui_chat_printf (NULL, "    gnutls: (not available)");
-#endif
+#endif /* HAVE_GNUTLS */
 
     /* display curl version */
 #ifdef LIBCURL_VERSION
     gui_chat_printf (NULL, "    curl: %s", LIBCURL_VERSION);
 #else
     gui_chat_printf (NULL, "    curl: (?)");
-#endif
+#endif /* LIBCURL_VERSION */
 
     /* display zlib version */
 #ifdef ZLIB_VERSION
     gui_chat_printf (NULL, "    zlib: %s", ZLIB_VERSION);
 #else
     gui_chat_printf (NULL, "    zlib: (?)");
-#endif
+#endif /* ZLIB_VERSION */
 
     return WEECHAT_RC_OK;
 }
@@ -584,7 +583,62 @@ debug_directories ()
 }
 
 /*
- * Hooks signals for debug.
+ * Starts time measure.
+ */
+
+void
+debug_time_start (const char *name)
+{
+    if (debug_time_name)
+    {
+        free (debug_time_name);
+        debug_time_name = NULL;
+    }
+    if (name)
+        debug_time_name = strdup (name);
+
+    gettimeofday (&debug_timeval_start, NULL);
+}
+
+/*
+ * Ends time measure and display elapsed time.
+ *
+ * If display is 1, the message is displayed in core buffer, otherwise it's
+ * written in log file.
+ */
+
+void
+debug_time_end (int display)
+{
+    struct timeval debug_timeval_end;
+    long long diff, diff_hour, diff_min, diff_sec, diff_usec;
+
+    gettimeofday (&debug_timeval_end, NULL);
+    diff = util_timeval_diff (&debug_timeval_start,
+                              &debug_timeval_end);
+
+    diff_usec = diff % 1000000;
+    diff_sec = (diff / 1000000) % 60;
+    diff_min = ((diff / 1000000) / 60) % 60;
+    diff_hour = (diff / 1000000) / 3600;
+
+    if (display)
+    {
+        gui_chat_printf (NULL,
+                         "debug: time[%s] -> %lld:%02lld:%02lld.%06d",
+                         (debug_time_name) ? debug_time_name : "?",
+                         diff_hour, diff_min, diff_sec, diff_usec);
+    }
+    else
+    {
+        log_printf ("debug: time[%s] -> %lld:%02lld:%02lld.%06d",
+                    (debug_time_name) ? debug_time_name : "?",
+                    diff_hour, diff_min, diff_sec, diff_usec);
+    }
+}
+
+/*
+ * Initializes debug.
  */
 
 void
@@ -598,3 +652,17 @@ debug_init ()
     hook_signal (NULL, "2000|debug_dump", &debug_dump_cb, NULL);
     hook_signal (NULL, "2000|debug_libs", &debug_libs_cb, NULL);
 }
+
+/*
+ * Ends debug.
+ */
+
+void
+debug_end ()
+{
+    if (debug_time_name)
+    {
+        free (debug_time_name);
+        debug_time_name = NULL;
+    }
+}
