@@ -1,7 +1,7 @@
 /*
  * wee-network.c - network functions
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2010 Emmanuel Bouthenot <kolter@openics.org>
  * Copyright (C) 2010 Gu1ll4um3r0m41n <aeroxteam@gmail.com>
  * Copyright (C) 2012 Simon Arlott
@@ -26,12 +26,20 @@
 #include "config.h"
 #endif
 
+/* _XPG4_2 is needed on SunOS for macros like CMSG_SPACE */
+/* __EXTENSIONS__ is needed on SunOS for constants like NI_MAXHOST */
+#ifdef __sun
+#define _XPG4_2
+#define __EXTENSIONS__
+#endif
+
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/select.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
@@ -60,7 +68,7 @@ int network_init_gnutls_ok = 0;
 
 #ifdef HAVE_GNUTLS
 gnutls_certificate_credentials_t gnutls_xcred; /* GnuTLS client credentials */
-#endif
+#endif /* HAVE_GNUTLS */
 
 
 /*
@@ -103,7 +111,7 @@ network_set_gnutls_ca_file ()
         }
         free (ca_path);
     }
-#endif
+#endif /* HAVE_GNUTLS */
 }
 
 /*
@@ -120,20 +128,17 @@ network_init_gnutls ()
         gnutls_certificate_allocate_credentials (&gnutls_xcred);
 
         network_set_gnutls_ca_file ();
-#if LIBGNUTLS_VERSION_NUMBER >= 0x02090a
-        /* for gnutls >= 2.9.10 */
+#if LIBGNUTLS_VERSION_NUMBER >= 0x02090a /* 2.9.10 */
         gnutls_certificate_set_verify_function (gnutls_xcred,
                                                 &hook_connect_gnutls_verify_certificates);
-#endif
-#if LIBGNUTLS_VERSION_NUMBER >= 0x020b00
-        /* for gnutls >= 2.11.0 */
+#endif /* LIBGNUTLS_VERSION_NUMBER >= 0x02090a */
+#if LIBGNUTLS_VERSION_NUMBER >= 0x020b00 /* 2.11.0 */
         gnutls_certificate_set_retrieve_function (gnutls_xcred,
                                                   &hook_connect_gnutls_set_certificates);
 #else
-        /* for gnutls < 2.11.0 */
         gnutls_certificate_client_set_retrieve_function (gnutls_xcred,
                                                          &hook_connect_gnutls_set_certificates);
-#endif
+#endif /* LIBGNUTLS_VERSION_NUMBER >= 0x020b00 */
     }
 #endif /* HAVE_GNUTLS */
 
@@ -155,7 +160,7 @@ network_end ()
             gnutls_certificate_free_credentials (gnutls_xcred);
             gnutls_global_deinit();
         }
-#endif
+#endif /* HAVE_GNUTLS */
         network_init_gnutls_ok = 0;
     }
 }
@@ -749,7 +754,7 @@ network_connect_child (struct t_hook *hook_connect)
     char msg_buf[CMSG_SPACE(sizeof (sock))];
     struct iovec iov[1];
     char iov_data[1] = { 0 };
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
     /*
      * indicates that something is wrong with whichever group of
      * servers is being tried first after connecting, so start at
@@ -796,7 +801,7 @@ network_connect_child (struct t_hook *hook_connect)
     hints.ai_socktype = SOCK_STREAM;
 #ifdef AI_ADDRCONFIG
     hints.ai_flags = AI_ADDRCONFIG;
-#endif
+#endif /* AI_ADDRCONFIG */
     if (ptr_proxy)
     {
         hints.ai_family = (CONFIG_BOOLEAN(ptr_proxy->options[PROXY_OPTION_IPV6])) ?
@@ -864,7 +869,7 @@ network_connect_child (struct t_hook *hook_connect)
         hints.ai_socktype = SOCK_STREAM;
 #ifdef AI_ADDRCONFIG
         hints.ai_flags = AI_ADDRCONFIG;
-#endif
+#endif /* AI_ADDRCONFIG */
         rc = getaddrinfo (HOOK_CONNECT(hook_connect, local_hostname),
                           NULL, &hints, &res_local);
         if (rc != 0)
@@ -1066,7 +1071,7 @@ network_connect_child (struct t_hook *hook_connect)
         sock = socket (ptr_res->ai_family,
                        ptr_res->ai_socktype,
                        ptr_res->ai_protocol);
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
         if (sock < 0)
         {
             status_str[0] = '0' + WEECHAT_HOOK_CONNECT_SOCKET_ERROR;
@@ -1197,7 +1202,7 @@ network_connect_child (struct t_hook *hook_connect)
 #else
         num_written = write (HOOK_CONNECT(hook_connect, child_write), &sock, sizeof (sock));
         (void) num_written;
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
     }
     else
     {
@@ -1292,7 +1297,7 @@ network_connect_gnutls_handshake_fd_cb (void *arg_hook_connect, int fd)
     {
         fcntl (HOOK_CONNECT(hook_connect, sock), F_SETFL,
                HOOK_CONNECT(hook_connect, handshake_fd_flags));
-#if LIBGNUTLS_VERSION_NUMBER < 0x02090a
+#if LIBGNUTLS_VERSION_NUMBER < 0x02090a /* 2.9.10 */
         /*
          * gnutls only has the gnutls_certificate_set_verify_function()
          * function since version 2.9.10. We need to call our verify
@@ -1309,7 +1314,7 @@ network_connect_gnutls_handshake_fd_cb (void *arg_hook_connect, int fd)
             unhook (hook_connect);
             return WEECHAT_RC_OK;
         }
-#endif
+#endif /* LIBGNUTLS_VERSION_NUMBER < 0x02090a */
         unhook (HOOK_CONNECT(hook_connect, handshake_hook_fd));
         (void) (HOOK_CONNECT(hook_connect, callback))
                 (hook_connect->callback_data,
@@ -1321,7 +1326,7 @@ network_connect_gnutls_handshake_fd_cb (void *arg_hook_connect, int fd)
 
     return WEECHAT_RC_OK;
 }
-#endif
+#endif /* HAVE_GNUTLS */
 
 /*
  * Timer callback for timeout of handshake.
@@ -1352,7 +1357,7 @@ network_connect_gnutls_handshake_timer_cb (void *arg_hook_connect,
 
     return WEECHAT_RC_OK;
 }
-#endif
+#endif /* HAVE_GNUTLS */
 
 /*
  * Reads connection progress from child process.
@@ -1367,7 +1372,7 @@ network_connect_child_read_cb (void *arg_hook_connect, int fd)
     long size_msg;
 #ifdef HAVE_GNUTLS
     int rc, direction;
-#endif
+#endif /* HAVE_GNUTLS */
     int sock;
 #ifdef HOOK_CONNECT_MAX_SOCKETS
     int i;
@@ -1377,7 +1382,7 @@ network_connect_child_read_cb (void *arg_hook_connect, int fd)
     char msg_buf[CMSG_SPACE(sizeof (sock))];
     struct iovec iov[1];
     char iov_data[1];
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
 
     /* make C compiler happy */
     (void) fd;
@@ -1457,7 +1462,7 @@ network_connect_child_read_cb (void *arg_hook_connect, int fd)
                 if (HOOK_CONNECT(hook_connect, sock_v6[i]) == sock)
                     HOOK_CONNECT(hook_connect, sock_v6[i]) = -1;
             }
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
 
             HOOK_CONNECT(hook_connect, sock) = sock;
 
@@ -1522,7 +1527,7 @@ network_connect_child_read_cb (void *arg_hook_connect, int fd)
                 }
                 fcntl (HOOK_CONNECT(hook_connect, sock), F_SETFL,
                        HOOK_CONNECT(hook_connect, handshake_fd_flags));
-#if LIBGNUTLS_VERSION_NUMBER < 0x02090a
+#if LIBGNUTLS_VERSION_NUMBER < 0x02090a /* 2.9.10 */
                 /*
                  * gnutls only has the gnutls_certificate_set_verify_function()
                  * function since version 2.9.10. We need to call our verify
@@ -1541,9 +1546,9 @@ network_connect_child_read_cb (void *arg_hook_connect, int fd)
                         free (cb_ip_address);
                     return WEECHAT_RC_OK;
                 }
-#endif
+#endif /* LIBGNUTLS_VERSION_NUMBER < 0x02090a */
             }
-#endif
+#endif /* HAVE_GNUTLS */
         }
         else
         {
@@ -1606,10 +1611,10 @@ network_connect_with_fork (struct t_hook *hook_connect)
     int i;
 #else
     int child_socket[2];
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
 #ifdef HAVE_GNUTLS
     const char *pos_error;
-#endif
+#endif /* HAVE_GNUTLS */
     pid_t pid;
 
 #ifdef HAVE_GNUTLS
@@ -1643,7 +1648,7 @@ network_connect_with_fork (struct t_hook *hook_connect)
         gnutls_transport_set_ptr (*HOOK_CONNECT(hook_connect, gnutls_sess),
                                   (gnutls_transport_ptr_t) ((unsigned long) HOOK_CONNECT(hook_connect, sock)));
     }
-#endif
+#endif /* HAVE_GNUTLS */
 
     /* create pipe for child process */
     if (pipe (child_pipe) < 0)
@@ -1677,7 +1682,7 @@ network_connect_with_fork (struct t_hook *hook_connect)
         HOOK_CONNECT(hook_connect, sock_v4[i]) = socket (AF_INET, SOCK_STREAM, 0);
         HOOK_CONNECT(hook_connect, sock_v6[i]) = socket (AF_INET6, SOCK_STREAM, 0);
     }
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
 
     switch (pid = fork ())
     {
@@ -1696,7 +1701,7 @@ network_connect_with_fork (struct t_hook *hook_connect)
             close (HOOK_CONNECT(hook_connect, child_read));
 #ifndef HOOK_CONNECT_MAX_SOCKETS
             close (HOOK_CONNECT(hook_connect, child_recv));
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
             network_connect_child (hook_connect);
             _exit (EXIT_SUCCESS);
     }
@@ -1707,7 +1712,7 @@ network_connect_with_fork (struct t_hook *hook_connect)
 #ifndef HOOK_CONNECT_MAX_SOCKETS
     close (HOOK_CONNECT(hook_connect, child_send));
     HOOK_CONNECT(hook_connect, child_send) = -1;
-#endif
+#endif /* HOOK_CONNECT_MAX_SOCKETS */
     HOOK_CONNECT(hook_connect, hook_child_timer) = hook_timer (hook_connect->plugin,
                                                                CONFIG_INTEGER(config_network_connection_timeout) * 1000,
                                                                0, 1,
