@@ -1,7 +1,7 @@
 /*
  * wee-util.c - some useful functions
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -103,6 +103,16 @@ struct t_rlimit_resource rlimit_resource[] =
 };
 #endif /* HAVE_SYS_RESOURCE_H */
 
+struct t_util_signal util_signals[] =
+{ { "hup", SIGHUP },
+  { "int", SIGINT },
+  { "quit", SIGQUIT },
+  { "kill", SIGKILL },
+  { "term", SIGTERM },
+  { "usr1", SIGUSR1 },
+  { "usr2", SIGUSR2 },
+  { NULL, 0 },
+};
 
 /*
  * Sets resource limit.
@@ -170,7 +180,7 @@ util_setrlimit_resource (const char *resource_name, long limit)
                      gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
                      resource_name);
 }
-#endif
+#endif /* HAVE_SYS_RESOURCE_H */
 
 /*
  * Sets resource limits using value of option "weechat.startup.sys_rlimit".
@@ -212,7 +222,7 @@ util_setrlimit ()
         }
         string_free_split (items);
     }
-#endif
+#endif /* HAVE_SYS_RESOURCE_H */
 }
 
 /*
@@ -227,6 +237,9 @@ util_setrlimit ()
 int
 util_timeval_cmp (struct timeval *tv1, struct timeval *tv2)
 {
+    if (!tv1 || !tv2)
+        return (tv1) ? 1 : ((tv2) ? -1 : 0);
+
     if (tv1->tv_sec < tv2->tv_sec)
         return -1;
     if (tv1->tv_sec > tv2->tv_sec)
@@ -241,13 +254,16 @@ util_timeval_cmp (struct timeval *tv1, struct timeval *tv2)
 /*
  * Calculates difference between two timeval structures.
  *
- * Returns difference in milliseconds.
+ * Returns difference in microseconds.
  */
 
-long
+long long
 util_timeval_diff (struct timeval *tv1, struct timeval *tv2)
 {
-    long diff_sec, diff_usec;
+    long long diff_sec, diff_usec;
+
+    if (!tv1 || !tv2)
+        return 0;
 
     diff_sec = tv2->tv_sec - tv1->tv_sec;
     diff_usec = tv2->tv_usec - tv1->tv_usec;
@@ -257,20 +273,24 @@ util_timeval_diff (struct timeval *tv1, struct timeval *tv2)
         diff_usec += 1000000;
         diff_sec--;
     }
-    return ((diff_usec / 1000) + (diff_sec * 1000));
+
+    return (diff_sec * 1000000) + diff_usec;
 }
 
 /*
- * Adds interval (in milliseconds) to a timeval structure.
+ * Adds interval (in microseconds) to a timeval structure.
  */
 
 void
-util_timeval_add (struct timeval *tv, long interval)
+util_timeval_add (struct timeval *tv, long long interval)
 {
-    long usec;
+    long long usec;
 
-    tv->tv_sec += (interval / 1000);
-    usec = tv->tv_usec + ((interval % 1000) * 1000);
+    if (!tv)
+        return;
+
+    tv->tv_sec += (interval / 1000000);
+    usec = tv->tv_usec + (interval % 1000000);
     if (usec > 1000000)
     {
         tv->tv_usec = usec % 1000000;
@@ -302,6 +322,28 @@ util_get_time_string (const time_t *date)
     return text_time;
 }
 
+/*
+ * Gets a signal number with a name; only some commonly used signal names are
+ * supported here (see declaration of util_signals[]).
+ *
+ * Returns the signal number, -1 if not found.
+ */
+
+int
+util_signal_search (const char *name)
+{
+    int i;
+
+    for (i = 0; util_signals[i].name; i++)
+    {
+        if (string_strcasecmp (util_signals[i].name, name) == 0)
+            return util_signals[i].signal;
+    }
+
+    /* signal not found */
+    return -1;
+}
+
 /*
  * Catches a system signal.
  */
@@ -460,7 +502,7 @@ util_exec_on_files (const char *directory, int hidden_files, void *data,
         {
             if (hidden_files || (entry->d_name[0] != '.'))
             {
-                snprintf (complete_filename, sizeof (complete_filename) - 1,
+                snprintf (complete_filename, sizeof (complete_filename),
                           "%s/%s", directory, entry->d_name);
                 lstat (complete_filename, &statbuf);
                 if (!S_ISDIR(statbuf.st_mode))
@@ -617,6 +659,9 @@ util_file_get_content (const char *filename)
     FILE *f;
     size_t count, fp;
 
+    if (!filename)
+        return NULL;
+
     buffer = NULL;
     fp = 0;
 
