@@ -29,6 +29,7 @@
 #include <string.h>
 #include <signal.h>
 #include <time.h>
+#include <sys/select.h>
 
 #include "../../core/weechat.h"
 #include "../../core/wee-command.h"
@@ -252,7 +253,7 @@ gui_main_debug_libs ()
                      NCURSES_VERSION, NCURSES_VERSION_PATCH);
 #else
     gui_chat_printf (NULL, "    ncurses: (?)");
-#endif
+#endif /* defined(NCURSES_VERSION) && defined(NCURSES_VERSION_PATCH) */
 }
 
 /*
