@@ -2,7 +2,7 @@
  * weechat-aspell.c - aspell plugin for WeeChat: color for misspelled words
  *
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2015 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2012 Nils Görs <weechatter@arcor.de>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -46,6 +46,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Spell checker for input (with Aspell)"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(9000);
 
 struct t_weechat_plugin *weechat_aspell_plugin = NULL;
 
@@ -53,7 +54,7 @@ int aspell_enabled = 0;
 
 #ifdef USE_ENCHANT
 EnchantBroker *broker = NULL;
-#endif
+#endif /* USE_ENCHANT */
 
 /*
  * aspell supported languages, updated on 2012-07-05
@@ -433,15 +434,15 @@ weechat_aspell_string_is_nick (struct t_gui_buffer *buffer, const char *word)
 int
 weechat_aspell_string_is_simili_number (const char *word)
 {
-    int utf8_char_int;
+    int code_point;
 
     if (!word || !word[0])
         return 0;
 
     while (word && word[0])
     {
-        utf8_char_int = weechat_utf8_char_int (word);
-        if (!iswpunct (utf8_char_int) && !iswdigit (utf8_char_int))
+        code_point = weechat_utf8_char_int (word);
+        if (!iswpunct (code_point) && !iswdigit (code_point))
             return 0;
         word = weechat_utf8_next_char (word);
     }
@@ -482,7 +483,7 @@ weechat_aspell_check_word (struct t_aspell_speller_buffer *speller_buffer,
             if (enchant_dict_check (speller_buffer->spellers[i], word, strlen (word)) == 0)
 #else
             if (aspell_speller_check (speller_buffer->spellers[i], word, -1) == 1)
-#endif
+#endif /* USE_ENCHANT */
                 return 1;
         }
     }
@@ -512,7 +513,7 @@ weechat_aspell_get_suggestions (struct t_aspell_speller_buffer *speller_buffer,
 #else
     const AspellWordList *list;
     AspellStringEnumeration *elements;
-#endif
+#endif /* USE_ENCHANT */
 
     max_suggestions = weechat_config_integer (weechat_aspell_config_check_suggestions);
     if (max_suggestions < 0)
@@ -584,7 +585,7 @@ weechat_aspell_get_suggestions (struct t_aspell_speller_buffer *speller_buffer,
                 }
                 delete_aspell_string_enumeration (elements);
             }
-#endif
+#endif /* USE_ENCHANT */
         }
     }
 
@@ -614,7 +615,7 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
     char *word_for_suggestions, *old_suggestions, *suggestions;
     char *word_and_suggestions;
     const char *color_normal, *color_error, *ptr_suggestions;
-    int utf8_char_int, char_size;
+    int code_point, char_size;
     int length, index_result, length_word, word_ok;
     int length_color_normal, length_color_error, rc;
     int input_pos, current_pos, word_start_pos, word_end_pos, word_end_pos_valid;
@@ -740,10 +741,10 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
             ptr_string_orig = NULL;
 
             /* find start of word: it must start with an alphanumeric char */
-            utf8_char_int = weechat_utf8_char_int (ptr_string);
-            while ((!iswalnum (utf8_char_int)) || iswspace (utf8_char_int))
+            code_point = weechat_utf8_char_int (ptr_string);
+            while ((!iswalnum (code_point)) || iswspace (code_point))
             {
-                if (!ptr_string_orig && !iswspace (utf8_char_int))
+                if (!ptr_string_orig && !iswspace (code_point))
                     ptr_string_orig = ptr_string;
                 char_size = weechat_utf8_char_size (ptr_string);
                 memcpy (result + index_result, ptr_string, char_size);
@@ -752,7 +753,7 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
                 current_pos++;
                 if (!ptr_string[0])
                     break;
-                utf8_char_int = weechat_utf8_char_int (ptr_string);
+                code_point = weechat_utf8_char_int (ptr_string);
             }
             if (!ptr_string[0])
                 break;
@@ -766,12 +767,12 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
             /* find end of word: ' and - allowed in word, but not at the end */
             ptr_end_valid = ptr_string;
             ptr_end = weechat_utf8_next_char (ptr_string);
-            utf8_char_int = weechat_utf8_char_int (ptr_end);
-            while (iswalnum (utf8_char_int) || (utf8_char_int == '\'')
-                   || (utf8_char_int == '-'))
+            code_point = weechat_utf8_char_int (ptr_end);
+            while (iswalnum (code_point) || (code_point == '\'')
+                   || (code_point == '-'))
             {
                 word_end_pos++;
-                if (iswalnum (utf8_char_int))
+                if (iswalnum (code_point))
                 {
                     /* pointer to last alphanumeric char in the word */
                     ptr_end_valid = ptr_end;
@@ -780,7 +781,7 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
                 ptr_end = weechat_utf8_next_char (ptr_end);
                 if (!ptr_end[0])
                     break;
-                utf8_char_int = weechat_utf8_char_int (ptr_end);
+                code_point = weechat_utf8_char_int (ptr_end);
             }
             ptr_end = weechat_utf8_next_char (ptr_end_valid);
             word_end_pos = word_end_pos_valid;
@@ -795,13 +796,13 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
                 word_ok = 1;
                 if (ptr_end[0])
                 {
-                    utf8_char_int = weechat_utf8_char_int (ptr_end);
-                    while (!iswspace (utf8_char_int))
+                    code_point = weechat_utf8_char_int (ptr_end);
+                    while (!iswspace (code_point))
                     {
                         ptr_end = weechat_utf8_next_char (ptr_end);
                         if (!ptr_end[0])
                             break;
-                        utf8_char_int = weechat_utf8_char_int (ptr_end);
+                        code_point = weechat_utf8_char_int (ptr_end);
                     }
                 }
             }
@@ -912,8 +913,8 @@ weechat_aspell_modifier_cb (void *data, const char *modifier,
             && (strcmp (old_suggestions, ptr_suggestions) != 0)))
     {
         weechat_bar_item_update ("aspell_suggest");
-        weechat_hook_signal_send ("aspell_suggest",
-                                  WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+        (void) weechat_hook_signal_send ("aspell_suggest",
+                                         WEECHAT_HOOK_SIGNAL_POINTER, buffer);
     }
     if (old_suggestions)
         free (old_suggestions);
@@ -1002,15 +1003,19 @@ weechat_aspell_debug_libs_cb (void *data, const char *signal,
     (void) signal_data;
 
 #ifdef USE_ENCHANT
+#ifdef HAVE_ENCHANT_GET_VERSION
     weechat_printf (NULL, "  %s: enchant %s",
                     ASPELL_PLUGIN_NAME, enchant_get_version ());
+#else
+    weechat_printf (NULL, "  %s: enchant (?)", ASPELL_PLUGIN_NAME);
+#endif /* HAVE_ENCHANT_GET_VERSION */
 #else
 #ifdef HAVE_ASPELL_VERSION_STRING
     weechat_printf (NULL, "  %s: aspell %s",
                     ASPELL_PLUGIN_NAME, aspell_version_string ());
 #else
     weechat_printf (NULL, "  %s: aspell (?)", ASPELL_PLUGIN_NAME);
-#endif
+#endif /* HAVE_ASPELL_VERSION_STRING */
 #endif /* USE_ENCHANT */
 
     return WEECHAT_RC_OK;
@@ -1034,7 +1039,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     broker = enchant_broker_init ();
     if (!broker)
         return WEECHAT_RC_ERROR;
-#endif
+#endif /* USE_ENCHANT */
 
     if (!weechat_aspell_speller_init ())
         return WEECHAT_RC_ERROR;
@@ -1090,7 +1095,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 #ifdef USE_ENCHANT
     /* release enchant broker */
     enchant_broker_free (broker);
-#endif
+#endif /* USE_ENCHANT */
 
     return WEECHAT_RC_OK;
 }
