@@ -1,7 +1,7 @@
 /*
  * irc-buffer.c - buffer functions for IRC plugin
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -141,16 +141,20 @@ irc_buffer_close_cb (void *data, struct t_gui_buffer *buffer)
         {
             if (ptr_server)
             {
-                /* send PART on all channels for server, then disconnect from server */
+                if (!ptr_server->disconnected)
+                {
+                    /* send QUIT to server, then disconnect */
+                    irc_command_quit_server (ptr_server, NULL);
+                    irc_server_disconnect (ptr_server, 0, 0);
+                }
                 ptr_channel = ptr_server->channels;
                 while (ptr_channel)
                 {
                     next_channel = ptr_channel->next_channel;
-                    weechat_buffer_close (ptr_channel->buffer);
+                    if (ptr_channel->buffer != buffer)
+                        weechat_buffer_close (ptr_channel->buffer);
                     ptr_channel = next_channel;
                 }
-                if (!ptr_server->disconnected)
-                    irc_server_disconnect (ptr_server, 0, 0);
                 ptr_server->buffer = NULL;
             }
         }
@@ -176,12 +180,22 @@ irc_buffer_nickcmp_cb (void *data,
                        const char *nick1,
                        const char *nick2)
 {
-    IRC_BUFFER_GET_SERVER(buffer);
+    struct t_irc_server *server;
 
-    /* make C compiler happy */
-    (void) data;
+    if (data)
+        server = (struct t_irc_server *)data;
+    else
+        irc_buffer_get_server_and_channel (buffer, &server, NULL);
 
-    return irc_server_strcasecmp (ptr_server, nick1, nick2);
+    if (server)
+    {
+        return irc_server_strcasecmp (server, nick1, nick2);
+    }
+    else
+    {
+        /* default is RFC 1459 casemapping comparison */
+        return weechat_strcasecmp_range (nick1, nick2, 29);
+    }
 }
 
 /*
