@@ -1,7 +1,7 @@
 /*
  * weechat-python.c - python plugin for WeeChat
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  * Copyright (C) 2012 Simon Arlott
  *
@@ -39,6 +39,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of python scripts"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_python_plugin = NULL;
 
@@ -83,7 +84,7 @@ static struct PyModuleDef moduleDefOutputs = {
     NULL,
     NULL
 };
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 
 /*
  * string used to execute action "install":
@@ -212,7 +213,7 @@ weechat_python_hashtable_map_cb (void *data,
 }
 
 /*
- * Gets python dictionary with a WeeChat hashtable.
+ * Converts a WeeChat hashtable to a python dictionary.
  */
 
 PyObject *
@@ -235,7 +236,7 @@ weechat_python_hashtable_to_dict (struct t_hashtable *hashtable)
 }
 
 /*
- * Gets WeeChat hashtable with python dictionary.
+ * Converts a python dictionary to a WeeChat hashtable.
  *
  * Note: hashtable must be freed after use.
  */
@@ -250,11 +251,8 @@ weechat_python_dict_to_hashtable (PyObject *dict, int size,
     Py_ssize_t pos;
     char *str_key, *str_value;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
@@ -269,19 +267,25 @@ weechat_python_dict_to_hashtable (PyObject *dict, int size,
                 str_key = strdup (PyBytes_AsString (key));
         }
         else
+        {
             str_key = weechat_python_unicode_to_string (key);
+        }
         if (PyBytes_Check (value))
         {
             if (PyBytes_AsString (value))
                 str_value = strdup (PyBytes_AsString (value));
         }
         else
+        {
             str_value = weechat_python_unicode_to_string (value);
+        }
 
         if (str_key)
         {
             if (strcmp (type_values, WEECHAT_HASHTABLE_STRING) == 0)
+            {
                 weechat_hashtable_set (hashtable, str_key, str_value);
+            }
             else if (strcmp (type_values, WEECHAT_HASHTABLE_POINTER) == 0)
             {
                 weechat_hashtable_set (hashtable, str_key,
@@ -315,9 +319,12 @@ weechat_python_exec (struct t_plugin_script *script,
     void *argv2[16], *ret_value;
     int i, argc, *ret_int;
 
+    ret_value = NULL;
+
     /* PyEval_AcquireLock (); */
 
     old_python_current_script = python_current_script;
+    python_current_script = script;
     old_interpreter = NULL;
     if (script->interpreter)
     {
@@ -335,13 +342,9 @@ weechat_python_exec (struct t_plugin_script *script,
                         weechat_gettext ("%s%s: unable to run function \"%s\""),
                         weechat_prefix ("error"), PYTHON_PLUGIN_NAME, function);
         /* PyEval_ReleaseThread (python_current_script->interpreter); */
-        if (old_interpreter)
-            PyThreadState_Swap (old_interpreter);
-        return NULL;
+        goto end;
     }
 
-    python_current_script = script;
-
     if (argv && argv[0])
     {
         argc = strlen (format);
@@ -364,8 +367,6 @@ weechat_python_exec (struct t_plugin_script *script,
         rc = PyObject_CallFunction (evFunc, NULL);
     }
 
-    ret_value = NULL;
-
     /*
      * ugly hack : rc = NULL while 'return weechat.WEECHAT_RC_OK ....
      * because of '#define WEECHAT_RC_OK 0'
@@ -391,11 +392,11 @@ weechat_python_exec (struct t_plugin_script *script,
             ret_value = NULL;
         Py_XDECREF(rc);
     }
-    else if ((ret_type == WEECHAT_SCRIPT_EXEC_INT) && (PyLong_Check (rc)))
+    else if ((ret_type == WEECHAT_SCRIPT_EXEC_INT) && (PY_INTEGER_CHECK(rc)))
     {
         ret_int = malloc (sizeof (*ret_int));
         if (ret_int)
-            *ret_int = (int) PyLong_AsLong(rc);
+            *ret_int = (int) PyLong_AsLong (rc);
         ret_value = ret_int;
         Py_XDECREF(rc);
     }
@@ -424,6 +425,7 @@ weechat_python_exec (struct t_plugin_script *script,
 
     /* PyEval_ReleaseThread (python_current_script->interpreter); */
 
+end:
     python_current_script = old_python_current_script;
 
     if (old_interpreter)
@@ -496,7 +498,7 @@ weechat_python_output (PyObject *self, PyObject *args)
 static PyObject *weechat_python_init_module_weechat ()
 #else
 void weechat_python_init_module_weechat ()
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 {
     PyObject *weechat_module, *weechat_dict;
 
@@ -506,7 +508,7 @@ void weechat_python_init_module_weechat ()
 #else
     /* python <= 2.x */
     weechat_module = Py_InitModule ("weechat", weechat_python_funcs);
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 
     if (!weechat_module)
     {
@@ -518,7 +520,7 @@ void weechat_python_init_module_weechat ()
         return NULL;
 #else
         return;
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
     }
 
     /* define some constants */
@@ -572,7 +574,7 @@ void weechat_python_init_module_weechat ()
 
 #if PY_MAJOR_VERSION >= 3
     return weechat_module;
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 }
 
 /*
@@ -589,7 +591,7 @@ weechat_python_load (const char *filename)
     char *argv[] = { "__weechat_plugin__" , NULL };
 #if PY_MAJOR_VERSION >= 3
     wchar_t *wargv[] = { NULL, NULL };
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
     FILE *fp;
     PyObject *weechat_outputs, *python_path, *path;
     const char *weechat_home;
@@ -634,7 +636,7 @@ weechat_python_load (const char *filename)
 #else
     /* python <= 2.x */
     PySys_SetArgv(1, argv);
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 
     if (!python_current_interpreter)
     {
@@ -665,7 +667,7 @@ weechat_python_load (const char *filename)
 #else
             /* python <= 2.x */
             path = PyBytes_FromString (str_home);
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
             if (path != NULL)
             {
                 PyList_Insert (python_path, 0, path);
@@ -682,7 +684,7 @@ weechat_python_load (const char *filename)
     /* python <= 2.x */
     weechat_outputs = Py_InitModule("weechatOutputs",
                                     weechat_python_output_funcs);
-#endif
+#endif /* PY_MAJOR_VERSION >= 3 */
 
     if (!weechat_outputs)
     {
@@ -720,11 +722,12 @@ weechat_python_load (const char *filename)
             PyErr_Print ();
 
         /* if script was registered, remove it from list */
-        if (python_current_script != NULL)
+        if (python_current_script)
         {
             plugin_script_remove (weechat_python_plugin,
                                   &python_scripts, &last_python_script,
                                   python_current_script);
+            python_current_script = NULL;
         }
 
         Py_EndInterpreter (python_current_interpreter);
@@ -766,8 +769,9 @@ weechat_python_load (const char *filename)
                                         &weechat_python_api_buffer_input_data_cb,
                                         &weechat_python_api_buffer_close_cb);
 
-    weechat_hook_signal_send ("python_script_loaded", WEECHAT_HOOK_SIGNAL_STRING,
-                              python_current_script->filename);
+    (void) weechat_hook_signal_send ("python_script_loaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING,
+                                     python_current_script->filename);
 
     return 1;
 }
@@ -794,7 +798,6 @@ weechat_python_unload (struct t_plugin_script *script)
 {
     int *rc;
     void *interpreter;
-    PyThreadState *old_interpreter;
     char *filename;
 
     if ((weechat_python_plugin->debug >= 2) || !python_quiet)
@@ -813,12 +816,13 @@ weechat_python_unload (struct t_plugin_script *script)
     }
 
     filename = strdup (script->filename);
-    old_interpreter = PyThreadState_Swap (NULL);
     interpreter = script->interpreter;
 
     if (python_current_script == script)
+    {
         python_current_script = (python_current_script->prev_script) ?
             python_current_script->prev_script : python_current_script->next_script;
+    }
 
     plugin_script_remove (weechat_python_plugin, &python_scripts, &last_python_script,
                           script);
@@ -829,11 +833,11 @@ weechat_python_unload (struct t_plugin_script *script)
         Py_EndInterpreter (interpreter);
     }
 
-    if (old_interpreter)
-        PyThreadState_Swap (old_interpreter);
+    if (python_current_script)
+        PyThreadState_Swap (python_current_script->interpreter);
 
-    weechat_hook_signal_send ("python_script_unloaded",
-                              WEECHAT_HOOK_SIGNAL_STRING, filename);
+    (void) weechat_hook_signal_send ("python_script_unloaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING, filename);
     if (filename)
         free (filename);
 }
@@ -958,6 +962,8 @@ weechat_python_command_cb (void *data, struct t_gui_buffer *buffer,
         {
             weechat_python_unload_all ();
         }
+        else
+            WEECHAT_COMMAND_ERROR;
     }
     else
     {
@@ -1007,13 +1013,7 @@ weechat_python_command_cb (void *data, struct t_gui_buffer *buffer,
             python_quiet = 0;
         }
         else
-        {
-            weechat_printf (NULL,
-                            weechat_gettext ("%s%s: unknown option for "
-                                             "command \"%s\""),
-                            weechat_prefix ("error"), PYTHON_PLUGIN_NAME,
-                            "python");
-        }
+            WEECHAT_COMMAND_ERROR;
     }
 
     return WEECHAT_RC_OK;
@@ -1149,7 +1149,7 @@ weechat_python_signal_debug_libs_cb (void *data, const char *signal,
     weechat_printf (NULL, "  %s: %s", PYTHON_PLUGIN_NAME, PY_VERSION);
 #else
     weechat_printf (NULL, "  %s: (?)", PYTHON_PLUGIN_NAME);
-#endif
+#endif /* PY_VERSION */
 
     return WEECHAT_RC_OK;
 }
