@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,11 +17,11 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_XFER_CHAT_H
-#define __WEECHAT_XFER_CHAT_H 1
+#ifndef WEECHAT_XFER_CHAT_H
+#define WEECHAT_XFER_CHAT_H 1
 
 extern void xfer_chat_sendf (struct t_xfer *xfer, const char *format, ...);
 extern int xfer_chat_recv_cb (void *arg_xfer, int fd);
 extern void xfer_chat_open_buffer (struct t_xfer *xfer);
 
-#endif /* __WEECHAT_XFER_CHAT_H */
+#endif /* WEECHAT_XFER_CHAT_H */
