@@ -36,6 +36,9 @@ extern "C"
 #define ONE_GB (ONE_MB * 1000ULL)
 #define ONE_TB (ONE_GB * 1000ULL)
 
+#define WEE_IS_WORD_CHAR(__result, __str)                               \
+    LONGS_EQUAL(__result, string_is_word_char_highlight (__str));       \
+    LONGS_EQUAL(__result, string_is_word_char_input (__str));
 #define WEE_HAS_HL_STR(__result, __str, __words)                        \
     LONGS_EQUAL(__result, string_has_highlight (__str, __words));
 
@@ -111,7 +114,7 @@ TEST(String, Duplicate)
     const char *str_test = "test";
     char *str;
 
-    str = string_strndup (NULL, 0);
+    POINTERS_EQUAL(NULL, string_strndup (NULL, 0));
 
     str = string_strndup (str_test, 0);
     CHECK(str);
@@ -415,23 +418,28 @@ TEST(String, ConvertEscapedChars)
 
 /*
  * Tests functions:
- *   string_is_word_char
+ *   string_is_word_char_highlight
+ *   string_is_word_char_input
  */
 
 TEST(String, IsWordChar)
 {
-    LONGS_EQUAL(0, string_is_word_char (NULL));
-    LONGS_EQUAL(0, string_is_word_char (""));
-    LONGS_EQUAL(0, string_is_word_char ("&abc"));
-    LONGS_EQUAL(0, string_is_word_char ("+abc"));
-    LONGS_EQUAL(0, string_is_word_char ("$abc"));
-    LONGS_EQUAL(0, string_is_word_char ("*abc"));
-    LONGS_EQUAL(0, string_is_word_char ("/abc"));
+    WEE_IS_WORD_CHAR(0, NULL);
+    WEE_IS_WORD_CHAR(0, "");
+    WEE_IS_WORD_CHAR(0, " abc");       /* space */
+    WEE_IS_WORD_CHAR(0, "\u00A0abc");  /* unbreakable space */
+    WEE_IS_WORD_CHAR(0, "&abc");
+    WEE_IS_WORD_CHAR(0, "+abc");
+    WEE_IS_WORD_CHAR(0, "$abc");
+    WEE_IS_WORD_CHAR(0, "*abc");
+    WEE_IS_WORD_CHAR(0, "/abc");
+    WEE_IS_WORD_CHAR(0, "\\abc");
 
-    LONGS_EQUAL(1, string_is_word_char ("abc"));
-    LONGS_EQUAL(1, string_is_word_char ("-abc"));
-    LONGS_EQUAL(1, string_is_word_char ("_abc"));
-    LONGS_EQUAL(1, string_is_word_char ("|abc"));
+    WEE_IS_WORD_CHAR(1, "abc");
+    WEE_IS_WORD_CHAR(1, "1abc");
+    WEE_IS_WORD_CHAR(1, "-abc");
+    WEE_IS_WORD_CHAR(1, "_abc");
+    WEE_IS_WORD_CHAR(1, "|abc");
 }
 
 /*
@@ -461,7 +469,7 @@ TEST(String, MaskToRegex)
 
 TEST(String, Regex)
 {
-    int flags, rc;
+    int flags;
     const char *ptr;
     regex_t regex;
 
@@ -531,11 +539,16 @@ TEST(String, Highlight)
     WEE_HAS_HL_STR(0, "", "");
     WEE_HAS_HL_STR(0, "test", "");
     WEE_HAS_HL_STR(0, "", "test");
+    WEE_HAS_HL_STR(0, "test-here", "test");
+    WEE_HAS_HL_STR(0, "this is a test here", "abc,def");
     WEE_HAS_HL_STR(1, "test", "test");
     WEE_HAS_HL_STR(1, "this is a test", "test");
     WEE_HAS_HL_STR(1, "test here", "test");
+    WEE_HAS_HL_STR(1, "test: here", "test");
+    WEE_HAS_HL_STR(1, "test : here", "test");
+    WEE_HAS_HL_STR(1, "test\u00A0here", "test");   /* unbreakable space */
+    WEE_HAS_HL_STR(1, "test\u00A0:here", "test");  /* unbreakable space */
     WEE_HAS_HL_STR(1, "this is a test here", "test");
-    WEE_HAS_HL_STR(0, "this is a test here", "abc,def");
     WEE_HAS_HL_STR(1, "this is a test here", "abc,test");
 
     /*
@@ -567,6 +580,9 @@ TEST(String, Highlight)
 char *
 test_replace_cb (void *data, const char *text)
 {
+    /* make C++ compiler happy */
+    (void) data;
+
     if (strcmp (text, "abc") == 0)
         return strdup ("def");
 
@@ -630,7 +646,6 @@ TEST(String, ReplaceRegex)
 
 TEST(String, ReplaceWithCallback)
 {
-    regex_t regex;
     char *result;
     int errors;
 
@@ -685,7 +700,7 @@ TEST(String, ReplaceWithCallback)
 
 TEST(String, Split)
 {
-    char **argv, *str;
+    char **argv;
     int argc;
 
     POINTERS_EQUAL(NULL, string_split (NULL, NULL, 0, 0, NULL));
@@ -756,7 +771,7 @@ TEST(String, Split)
 
 TEST(String, SplitShared)
 {
-    char **argv, *str;
+    char **argv;
     int argc;
 
     POINTERS_EQUAL(NULL, string_split_shared (NULL, NULL, 0, 0, NULL));
@@ -789,7 +804,7 @@ TEST(String, SplitShared)
 
 TEST(String, SplitShell)
 {
-    char **argv, *str;
+    char **argv;
     int argc;
 
     POINTERS_EQUAL(NULL, string_split_shell (NULL, NULL));
@@ -826,8 +841,7 @@ TEST(String, SplitShell)
 
 TEST(String, SplitCommand)
 {
-    char **argv, *str;
-    int argc;
+    char **argv;
 
     POINTERS_EQUAL(NULL, string_split_command (NULL, ';'));
     POINTERS_EQUAL(NULL, string_split_command ("", ';'));
@@ -966,8 +980,6 @@ TEST(String, FormatSize)
 TEST(String, BaseN)
 {
     char str[1024];
-    const char *str_abc = "abc";
-    const char *str_abc_base64 = "YWJj";
     const char *str_base64[][2] =
         { { "", "" },
           { "A", "QQ==" },
